@@ -1,5 +1,3 @@
-/* $Id: shm_limits.h 2482 2006-04-18 20:17:25Z gpoo $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -60,10 +58,10 @@ void glibtop_get_shm_limits(glibtop_shm_limits *buf);
 void glibtop_get_shm_limits_l (glibtop *server, glibtop_shm_limits *buf);
 
 #if GLIBTOP_SUID_SHM_LIMITS
-void glibtop_init_shm_limits_p (glibtop *server);
+void _glibtop_init_shm_limits_p (glibtop *server);
 void glibtop_get_shm_limits_p (glibtop *, glibtop_shm_limits *buf);
 #else
-void glibtop_init_shm_limits_s (glibtop *server);
+void _glibtop_init_shm_limits_s (glibtop *server);
 void glibtop_get_shm_limits_s (glibtop *server, glibtop_shm_limits *buf);
 #endif
 
