@@ -1,5 +1,3 @@
-/* $Id: procmem.c,v 1.5 2004/10/22 15:35:57 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <unistd.h>
 #include <sys/vminfo.h>
 #include <sys/resource.h>
@@ -39,7 +38,7 @@ static const unsigned long _glibtop_sysdeps_proc_mem =
 /* Init function. */
 
 void
-glibtop_init_proc_mem_s (glibtop *server)
+_glibtop_init_proc_mem_s (glibtop *server)
 {
 	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
