@@ -29,7 +29,7 @@ static const unsigned long _glibtop_sysdeps_proc_args = 0;
 /* Init function. */
 
 void
-glibtop_init_proc_args_p (glibtop *server)
+_glibtop_init_proc_args_p (glibtop *server)
 {
 	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
 }
