@@ -1,5 +1,3 @@
-/* $Id: msg_limits.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -33,7 +31,7 @@ static const unsigned long _glibtop_sysdeps_msg_limits = 0;
 /* Init function. */
 
 void
-glibtop_init_msg_limits_p (glibtop *server)
+_glibtop_init_msg_limits_p (glibtop *server)
 {
 	server->sysdeps.msg_limits = _glibtop_sysdeps_msg_limits;
 }
